==> tkhr-0.1.0.tar.gz: tkhr-0.1.0/README.md <==
# TkinterHotReload

A powerful hot reload utility for Tkinter applications that enables real-time code updates without restarting your application.

## Features

- 🔄 Live code reloading for Tkinter applications
- 🚀 Zero configuration required
- 🎯 Automatic detection of file changes
- 💻 Seamless development experience
- 🛠 Maintains application state during reloads

## Installation

Install TkinterHotReload using pip:

```bash
pip install tkhotreload
```

## Quick Start

Here's a simple example of how to use TkinterHotReload:

```python
from tkinter import Tk, Label
from tkhotreload import HotReloader

class App(Tk):
    def __init__(self):
        super().__init__()
        self.title("Hot Reload Demo")
        Label(self, text="Edit this file and save to see changes!").pack(pady=20)

if __name__ == "__main__":
    app = App()
    hot_reloader = HotReloader(app)
    app.mainloop()
```

## How It Works

TkinterHotReload monitors your Python files for changes. When you modify and save a file, it automatically:

1. Detects the changes in your code
2. Reloads the modified modules
3. Updates your Tkinter application while preserving its state

## Advanced Usage

### Custom Watch Patterns

```python
from tkhotreload import HotReloader

# Watch specific files or patterns
hot_reloader = HotReloader(app, paths=["app.py", "modules/*.py"])
```

### Reload Callbacks

```python
from tkhotreload import HotReloader

def on_reload():
    print("Code reloaded!")

hot_reloader = HotReloader(app, on_reload=on_reload)
```

## Contributing

Contributions are welcome! Here's how you can help:

1. Fork the repository
2. Create a feature branch (`git checkout -b feature/amazing-feature`)
3. Commit your changes (`git commit -m 'Add amazing feature'`)
4. Push to the branch (`git push origin feature/amazing-feature`)
5. Open a Pull Request

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Support

If you encounter any issues or have questions, please:

- Open an issue on GitHub
- Check existing issues for solutions
- Provide detailed information about your problem

## Acknowledgments

- Thanks to all contributors who have helped shape TkinterHotReload
- Inspired by hot reload functionality in modern web development

---

Made with ❤️ for the Python community

==> tkhr-0.1.1.tar.gz: tkhr-0.1.1/README.md <==
# TkinterHotReload

A powerful hot reload utility for Tkinter applications that enables real-time code updates without restarting your application.

## Features

- 🔄 Live code reloading for Tkinter applications
- 🚀 Zero configuration required
- 🎯 Automatic detection of file changes
- 💻 Seamless development experience
- 🛠 Maintains application state during reloads

## Installation

Install TkinterHotReload using pip:

```bash
pip install tkhotreload --upgrade
```

## Quick Start

Here's a simple example of how to use TkinterHotReload:

```python
import tkhotreload as tkhr
from tkinter import Label, Button


def main(root: tkhr.TkinterHotReload):
    # Use the new properties method to set multiple attributes at once
    root.properties(
        title="Tk Inter Reload",
        always_on_top=True,
        alpha=0.5,
        icon="icon.ico",
        debug=False,
    )
    Label(root, text="Change this and save!").pack(pady=20)
    Button(root, text="Click me", command=lambda: print("Clicked!")).pack()


tkhr.app(target=main, watch_dir=".", exclude=["*.pyc", "__pycache__"])
```

## How It Works

TkinterHotReload monitors your Python files for changes. When you modify and save a file, it automatically:

1. Detects the changes in your code
2. Reloads the modified modules
3. Updates your Tkinter application while preserving its state

## Contributing

Contributions are welcome! Here's how you can help:

1. Fork the repository
2. Create a feature branch
3. Commit your changes
4. Push to the branch
5. Open a Pull Request

## License

This project is licensed under the MIT License - see the LICENSE file for details.

## Support

If you encounter any issues or have questions, please:

- Open an issue on GitHub
- Check existing issues for solutions
- Provide detailed information about your problem

## Acknowledgments

- Thanks to all contributors who have helped shape TkinterHotReload
- Inspired by hot reload functionality in modern web development

---

Made with ❤️ for the Python community
